#!/bin/sh

# download and package chrome, vivaldi or opera
# 4th revision

[ $(id -u) -ne 0 ] && exec sudo -A ${0} ${@}

export TEXTDOMAIN=dl_browser.sh
export OUTPUT_CHARSET=UTF-8

# func strings
export ERR_TITLE=$(gettext 'Download a browser - error')
export TTLE=$(gettext 'file exists')
export EX=$(gettext ' already exists in /mnt/home. Load it or move it! Exiting.')

. /etc/rc.d/PUPSTATE
. /usr/share/dl_browser/browser.func

export PUP_HOME

# check deps - ar is on devx
ND_MSG=$(gettext 'ar and bsdtar utilities are missing. Install binutils or devx for the ar utility or libarchive for the bsdtar utility.')
if ! command -v bsdtar 2>&1 >/dev/null; then
	if ! command -v ar 2>&1 >/dev/null; then
		init_error "$ND_MSG"
	fi
fi

# check connection
NOCON=$(gettext 'It seems you are not connected to the internet. Exiting.')
check_internet 2>&1 > /dev/null || init_error "$NOCON"

# tmp
TMP=${TMP:-/tmp}

# check install type
state=true
MSG3=$(gettext "Choose if you want a pet package or sfs package")
case $PUPMODE in
	2|3|5|77)state=false
			MSG3=$(gettext "Your type of install only supports PET packages");;
esac

# check arch
arch=`uname -m`

case $arch in
	i?86)CHROME=false # no 32 bit chrome
		VIVALDI=true
		OPERA=true
		MSG1=$(gettext "There is no 32 bit package for chrome. You can however download latest Vivaldi or Opera and create and install a Puppy package.")
		MSG2=$(gettext "Just hit the Vivaldi or Opera button to install and the download will start")
		DEBARCH=i386
		CARCH=$DEBARCH;;
	x86_64)CHROME=true
		VIVALDI=true
		OPERA=true
		MSG1=$(gettext "You can download the latest Chrome, Vivaldi or Opera browser and create and install a Puppy package.")
		MSG2=$(gettext "Just hit the button of the browser you wish to install and the download will start")
		DEBARCH=amd64
		CARCH=$arch;;
	*)exit;;
esac

# find icons
PETICON=/usr/share/pixmaps/puppy/package_pet.svg
SFSICON=/usr/share/pixmaps/puppy/package_sfs.svg
ICONTHEME=`grep -i 'icon-theme' ~/.gtkrc-2.0|sed 's/^gtk-icon-theme-name = //'`
if echo "$ICONTHEME"| grep -q 'Puppy Flat';then
		PETICON="/usr/share/icons/Puppy Flat/48/mimetypes/application-pet.svg"
		SFSICON="/usr/share/icons/Puppy Flat/48/mimetypes/application-x-squashfs-image.svg"
fi
	
# check if installed ####
# but wait..
gtkdialog-splash -close never -bg CornflowerBlue -text "$(gettext 'Please wait... checking latest versions')" &
export apid=$!
# chrome
if [ "$CARCH" = 'x86_64' ];then
  read xx yy CUR_CVERSION <<< $(google-chrome-stable --version 2>/dev/null)
  NEW_CVERSION=$(wget -qO- https://dl.google.com/linux/direct/google-chrome-stable_current_x86_64.rpm | head -c96 | strings | rev | awk -F"[:-]" '/emorhc/ { print $1 "-" $2 }' | rev)
  if echo $NEW_CVERSION | grep -Fq '-'; then
    GOOGLEREVISION=${NEW_CVERSION#*-}
  NEW_CVERSION=${NEW_CVERSION%-*}
  else
    GOOGLEREVISION=""
  fi
fi
# vivaldi
read zz CUR_VVERSION <<< $(vivaldi-stable --version 2>/dev/null)
NEW_VVERSION=$(wget -qO- http://repo.vivaldi.com/archive/deb/dists/stable/main/binary-$DEBARCH/Packages.gz | gzip -d | grep -A6 -x "Package: vivaldi-stable" | sed -n "/Version/s/.* //p" | sort | tail -n 1)
if echo $NEW_VVERSION | grep -Fq '-'; then
  VIVALDIREVISION=${NEW_VVERSION#*-}
  NEW_VVERSION=${NEW_VVERSION%-*}
else
  VIVALDIREVISION=""
fi

# opera
NEW_OVERSION=$(wget -qO- http://deb.opera.com/opera/dists/stable/non-free/binary-$DEBARCH/Packages.gz | gzip -d | grep -A1 -x "Package: opera-stable" | sed -n "/Version/s/.* //p")
CUR_OVERSION=$(opera --version 2>/dev/null)

# common
BGUI=''
for CUR in google-chrome vivaldi opera
do
	case "$CUR" in
		google-chrome)VER="$CUR_CVERSION";NVER="$NEW_CVERSION"
			[ "$CARCH" = 'i386' ] && continue;; # no 32 bit
		vivaldi)VER="$CUR_VVERSION";NVER="$NEW_VVERSION";;
		opera)VER="$CUR_OVERSION";NVER="$NEW_OVERSION";;
	esac
	# check sfs exists in /mnt/home and not loaded
	XVER=''
	case "$CUR" in
		vivaldi)[ -n "${VIVALDIREVISION}" ] && XVER="-${VIVALDIREVISION}";;
	esac
	echo ${CUR}-${NVER}${XVER}-${CARCH}.sfs
	# this stops the program on the first match
	check_sfs_exists ${CUR}-${NVER}${XVER}-${CARCH}.sfs
	# check latest installed
	echo "$VER" "$NVER"
	if [ "$VER" = "$NVER" ];then
		case "$CUR" in
			google-chrome)CHROME=false;;
			vivaldi)VIVALDI=false;;
			opera)OPERA=false;;
		esac
		echo $CHROME $VIVALDI $OPERA
		continue
	fi
	[ -z "$VER" ] && continue
	#check if sfs or pet
	is_pet_installed $CUR
	if [ $? -eq 1 ];then
		is_sfs_loaded $CUR
		if [ $? -eq 0 ];then
			ICON=$SFSICON
			ACT=unload
			PROG=sfs_load
		fi
	else
		ICON=$PETICON
		ACT=uninstall
		PROG=petget
	fi
	# add to main gui
	TBASE1=$(gettext ', an older version is installed. Uninstall it with ')
	TBASE2=$(gettext ' - button on left - and run this program again later.')
	BGUI="$BGUI"'<hbox space-expand="true" space-fill="true">
			<button space-expand="false" space-fill="true">
			  <input file>'$ICON'</input>
			  <width>32</width><height>32</height>
			  <action function="exit">'$ACT'</action>
			</button>
			<text use-markup="true" space-expand="true" space-fill="false" justify="2">
			  <label>"<i>'${CUR}-${VER}${TBASE1}${PROG}${TBASE2}'</i>"</label>
			</text>
		</hbox>'
		echo $CHROME $VIVALDI $OPERA
done
[ -n "$BGUI" ] && BGUI='<vbox space-expand="true" space-fill="false">'$BGUI'</vbox>'
####

SPOT_MSG=$(gettext "All browsers will run as unprivileged user Spot")

if [ "$CHROME" = 'true' ]; then
  CH='<button image-position="top">
			<label>Chrome</label>
			<variable>btnch</variable>
			<input file>/usr/share/pixmaps/chrome.svg</input>
		</button>'
else
  CH=''
fi
if [ "$VIVALDI" = 'true' ]; then
  VI='<button image-position="top">
			<label>Vivaldi</label>
			<variable>btnvi</variable>
			<input file>/usr/share/pixmaps/vivaldi.svg</input>
		</button>'
else
  VI=''
fi
if [ "$OPERA" = 'true' ]; then
  OP='<button image-position="top">
			<label>Opera</label>
			<variable>btnop</variable>
			<input file>/usr/share/pixmaps/opera.svg</input>
		</button>'
else
  OP=''
fi
ALT=''
CHOICE='<frame>
	  <hbox homogeneous="true">
	    <text><label>'"$MSG3"'</label></text>
	  </hbox>
	  <hbox homogeneous="true">
	      <pixmap>
	        <width>32</width>
			<height>32</height>
	        <input file>'"$PETICON"'</input>
	      </pixmap>
	      <radiobutton>
			<label>PET</label>
			<variable>RADIOBUTTON1</variable>
		  </radiobutton>
	      <pixmap>
	        <width>32</width>
			<height>32</height>
	        <input file>'"$SFSICON"'</input>
	        <sensitive>'$state'</sensitive>
	      </pixmap>		  
	      <radiobutton>
			<label>SFS</label>
			<sensitive>'$state'</sensitive>
			<variable>RADIOBUTTON2</variable>
		  </radiobutton>
		  
	  </hbox>
	  </frame>'
if [ "$CHROME" = 'false' -a "$VIVALDI" = 'false' -a "$OPERA" = 'false' ];then
  ALTMSG=$(gettext 'All offered browsers are up to date, so the choice is simple!')
  ALT='<text><label>'$ALTMSG'</label></text>';MSG2=$(gettext 'Congratulations');CHOICE=''
fi
case $CARCH in
  x86_64)
	if [ "$CHROME" = 'true' -a "$VIVALDI" = 'false' -a "$OPERA" = 'false' ];then
	  MSG2=$(gettext 'Only Chrome is available. Opera and Vivaldi are up to date')
	elif [ "$CHROME" = 'true' -a "$VIVALDI" = 'true' -a "$OPERA" = 'false' ];then 
	  MSG2=$(gettext 'Only Chrome and Vivaldi are available. Opera is up to date')
	elif [ "$CHROME" = 'true' -a "$VIVALDI" = 'false' -a "$OPERA" = 'true' ];then 
	  MSG2=$(gettext 'Only Chrome and Opera are available. Vivaldi is up to date')
	elif [ "$CHROME" = 'false' -a "$VIVALDI" = 'false' -a "$OPERA" = 'true' ];then 
	  MSG2=$(gettext 'Only Opera is available. Chrome and Vivaldi are up to date')
	elif [ "$CHROME" = 'false' -a "$VIVALDI" = 'true' -a "$OPERA" = 'true' ];then 
	  MSG2=$(gettext 'Only Vivaldi and Opera are available. Chrome is up to date')
	elif [ "$CHROME" = 'false' -a "$VIVALDI" = 'true' -a "$OPERA" = 'false' ];then 
	  MSG2=$(gettext 'Only Vivaldi is available. Chrome and Opera are up to date')
	fi ;;
  *)
	if [ "$VIVALDI" = 'true' -a "$OPERA" = 'false' ];then
	  MSG2=$(gettext 'Only Vivaldi is available. Opera is up to date')
	elif [ "$VIVALDI" = 'false' -a "$OPERA" = 'true' ];then
	  MSG2=$(gettext 'Only Opera is available. Vivaldi is up to date')
	fi ;;
esac

kill -9 $apid

# main dialog
export DLG='<window title="'$(gettext 'Download a browser')'" icon-name="gtk-preferences">
	<vbox width-request="500">
	'"`/usr/lib/gtkdialog/xml_info fixed /usr/share/pixmaps/dl_browser.svg 60 "$MSG1"`"' 
	  '$CHOICE'
	  <frame>
	  '$BGUI'
	  <hbox homogeneous="true">
	    <text><label>'"$MSG2"'</label></text>
	  </hbox>
	  <hbox homogeneous="true">  
	      '$CH'
	      '$VI'
	      '$OP'
	      '$ALT'
	  </hbox>
	  </frame>
	  <hbox homogeneous="true">
	    <text use-markup="true">
	      <label>"<span fgcolor='"'darkgreen'"'><i>'"$SPOT_MSG"'</i></span>"</label>
	    </text>
	  </hbox>
	  <hbox>
	    <button cancel></button>
	  </hbox>
	</vbox>
</window>'

. /usr/lib/gtkdialog/xml_info gtk
PKG_TYPE='pet'
case $1 in
 -d)echo "$DLG";;
 *)eval $(gtkdialog -p DLG);;
esac
# package type
if [ "$RADIOBUTTON2" = 'true' ];then
	PKG_TYPE='sfs'
fi
case $EXIT in
	unload)unload_sfs;;
	uninstall)uninstall_pet;;
esac
PKG=$EXIT
case $PKG in
	Vivaldi) PKG_TYPE=$PKG_TYPE urxvt -bg green -fg blue --geometry 80x10+1+1 -e install-vivaldi.sh;;
	Chrome) PKG_TYPE=$PKG_TYPE urxvt -bg green -fg blue --geometry 80x10+1+1 -e latest-chrome.sh;;
	Opera) PKG_TYPE=$PKG_TYPE urxvt -bg green -fg blue --geometry 80x10+1+1 -e latest-opera.sh;;
	*)exit;;
esac
FMSG=$(gettext "failed to be generated.")
SMSG=$(gettext "is located in /tmp. You can choose to save it before you shut down your computer.")
# find the package
PACKAGE=`ls ${TMP} | grep -io "${PKG}.*" | grep  "${PKG_TYPE}$" | tail -1` # tail in case of older pkg
PACKAGE=`ls ${TMP} | grep "${PACKAGE}"` # chrome
[ -z "$PACKAGE" -o ! -f "${TMP}/$PACKAGE" ] &&  gtkdialog-splash -bg orange -close box -timeout 6 \
-text "$PKG $PKG_TYPE $FMSG" && exit 1
gtkdialog-splash -bg green -close box -timeout 10 \
-text "$PACKAGE $SMSG"
# install
case $PACKAGE in 
	*.pet)petget +${TMP}/${PACKAGE};;
	*.sfs)sfs_load +${TMP}/${PACKAGE};;
esac

# END
